@@ -1,7 +1,7 @@
 from argparse import Action
 from datetime import datetime, time, timedelta
 
-from .api.types import CarriageType, SeatsAvailabilityResponse, TimeDict, TrainComposition
+from .api.types import SeatsAvailabilityResponse, TimeDict, TrainComposition
 
 
 def parse_datetime(s: str):
@@ -69,6 +69,7 @@ TRANSLITERATIONS = {
     "ź": "z",
     "ż": "z",
     " ": "-",
+    "/": "-",
     "_": "-",
 }
 
@@ -124,7 +125,7 @@ BRAND_SEAT_TYPE_MAPPING = {
 }
 
 
-def find_empty_compartments(seats: SeatsAvailabilityResponse, composition: TrainComposition) -> list[tuple[int, int]]:
+def find_empty_compartments(seats: SeatsAvailabilityResponse) -> list[tuple[int, int]]:
     num_taken_seats_in_group: dict[tuple[int, int], int] = {}
     for seat in seats["seats"]:
         key = (int(seat["carriage_nr"]), int(seat["seat_nr"][:-1]))
